<?php

add_action( 'init', 'scoutingnl_menus' );
function scoutingnl_menus() {

	$waar = array(
		'hoofdmenu'  => __( 'hoofdnavigatie', 'scoutingnl' ),
		'footermenu' => __( 'footernavigatie', 'scoutingnl' ),
	);
	register_nav_menus( $waar );

}

/**
 * Register a widget area.
 */

register_sidebar(

	array(

		'name'          => 'Sidebar widgets',
		'id'            => 'sidebar-widgetarea',
		'description'   => 'Hier kun je een widget plaatsen, een GA blok of iets anders ...',
		'before_widget' => '<div id="%1$s" class="widget sidebar">',
		'after_widget'  => '</div>',
		'before_title'  => '',
		'after_title'   => '',

	)
);

register_sidebar(

	array(
		'name'          => 'Footer widgets',
		'id'            => 'footer-widgetarea',
		'description'   => 'Footer widgets [rechts]',
		'before_widget' => '<div class="widget footer">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	)
);

/**
 * ACF Posts widget - custom widget that loads and shows content of the ACF post_object field
 */

class ACF_Posts_Widget extends WP_Widget {

	/**
	* Register widget with WordPress.
	*/
	function __construct() {
		parent::__construct(
			'acf_posts_widget',
			__( 'ACF Pagina\'s en berichten Widget', 'scoutingnl' ),
			array(
				'description' => __( 'Widget waarin ACF post objects worden getoond', 'scoutingnnl' ),
				'classname'   => 'acf-posts-widget',
			)
		);
	}

	/**
	* Front-end display of widget.
	*
	* @see WP_Widget::widget()
	*
	* @param array $args     Widget arguments.
	* @param array $instance Saved values from database.
	*/
	public function widget( $args, $instance ) {

		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$widget_id = 'widget_' . $args['widget_id'];
		echo $args['before_widget'];
		$subtitel = get_field( 'subtitel', $widget_id ) ? get_field( 'subtitel', $widget_id ) : '';
		$posts    = get_field( 'posts', $widget_id ) ? get_field( 'posts', $widget_id ) : '';

		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		if ( $subtitel ) {
			echo '<p>' . $subtitel . '</p>';
		}
		if ( $posts ) {
			echo '<ul class="footer-links">';
			foreach ( $posts as $post ) {
				echo '<li><a href="' . get_permalink( $post ) . '">' . get_the_title( $post ) . '</a></li>';
			}
			echo '</ul>';
		}

		echo $args['after_widget'];

	}

	/**
	* Back-end widget form.
	*
	* @see WP_Widget::form()
	*
	* @param array $instance Previously saved values from database.
	*/
	public function form( $instance ) {

		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'New title', 'lvk' );
		}
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>

		<?php

	}

	/**
	* Sanitize widget form values as they are saved.
	*
	* @see WP_Widget::update()
	*
	* @param array $new_instance Values just sent to be saved.
	* @param array $old_instance Previously saved values from database.
	*
	* @return array Updated safe values to be saved.
	*/
	public function update( $new_instance, $old_instance ) {

		$instance          = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';

		return $instance;
	}

}

add_action(
	'widgets_init',
	function() {

		register_widget( 'ACF_Posts_Widget' );

	}
);


/**
 * ACF Gallery widget - custom widget that loads and shows an ACF gallery field
 */

class ACF_Gallery_Widget extends WP_Widget {

	/**
	* Register widget with WordPress.
	*/
	function __construct() {
		parent::__construct(
			'acf_gallery_widget',
			__( 'ACF Gallery Widget', 'scoutingnl' ),
			array(
				'description' => __( 'Widget waarin afbeeldingen van een ACF gallery worden getoond', 'scoutingnl' ),
				'classname'   => 'acf-gallery-widget',
			)
		);
	}

	/**
	* Front-end display of widget.
	*
	* @see WP_Widget::widget()
	*
	* @param array $args     Widget arguments.
	* @param array $instance Saved values from database.
	*/
	public function widget( $args, $instance ) {

		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$widget_id = 'widget_' . $args['widget_id'];
		echo $args['before_widget'];
		$subtitel = get_field( 'subtitel', $widget_id ) ? get_field( 'subtitel', $widget_id ) : '';
		$images   = get_field( 'gallery', $widget_id ) ? get_field( 'gallery', $widget_id ) : '';

		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		if ( $subtitel ) {
			echo '<p>' . $subtitel . '</p>';
		}
		if ( $images ) {
			echo '<ul class="row no-gutters footer-gallery chocolat-container">';
			foreach ( $images as $image ) {
				echo '<li class="col-3"><a class="chocolat-image" href="' . $image['url'] . '" target="_blank"><img alt="" class="img-fluid lazyload" src="' . $image['sizes']['thumbnail'] . '" /></a></li>';
			}
			echo '</ul>';
		}

		echo $args['after_widget'];

	}

	/**
	* Back-end widget form.
	*
	* @see WP_Widget::form()
	*
	* @param array $instance Previously saved values from database.
	*/
	public function form( $instance ) {

		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'New title', 'scoutingnl' );
		}
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>

		<?php

	}

	/**
	* Sanitize widget form values as they are saved.
	*
	* @see WP_Widget::update()
	*
	* @param array $new_instance Values just sent to be saved.
	* @param array $old_instance Previously saved values from database.
	*
	* @return array Updated safe values to be saved.
	*/
	public function update( $new_instance, $old_instance ) {

		$instance          = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';

		return $instance;
	}

}

add_action(
	'widgets_init',
	function() {

		register_widget( 'ACF_Gallery_Widget' );

	}
);
