<?php

/* ===  Hide specific plugins from plugins list === */

add_action( 'pre_current_active_plugins', 'hide_plugin_puc' );
function hide_plugin_puc() {
	global $wp_list_table;
	$hidearr = array(
		// 'advanced-custom-fields-pro/acf.php',
		'plugin-update-checker/plugin-update-checker.php',
	);
	$plugins = $wp_list_table->items;
	foreach ( $plugins as $key => $val ) {
		if ( in_array( $key, $hidearr ) ) {
			unset( $wp_list_table->items[ $key ] );
		}
	}
}

/* ===  Hide update notifications by specific plugins === */

add_filter( 'site_transient_update_plugins', 'remove_update_notifications' );
function remove_update_notifications( $value ) {

	// if ( isset( $value ) && is_object( $value ) ) {
	// 	unset( $value->response['advanced-custom-fields-pro/acf.php'] );
	// }

	return $value;

}

/* === ACF - add option page with site setting === */

if ( function_exists( 'acf_add_options_page' ) ) {
	acf_add_options_page( 'Site Settings' );
}


/**
 * ACF: Hide / show the ACF menu in wp-admin
 */

// add_filter( 'acf/settings/show_admin', '__return_false' );


/**
 * ACF: ACF JSON location
 */

add_filter( 'acf/settings/save_json', 'scoutingnl_acf_json_save_point' );
function scoutingnl_acf_json_save_point( $path ) {

	$path = get_stylesheet_directory() . '/acf-json';
	return $path;

}


add_filter( 'acf/settings/load_json', 'scoutingnl_acf_json_load_point' );
function scoutingnl_acf_json_load_point( $paths ) {

	unset( $paths[0] );
	$paths[] = get_stylesheet_directory() . '/acf-json';
	return $paths;

}

/* === ACF - add Google Maps API key in order to avoid "development purposes only" message in wp-admin === */

add_filter(
	'acf/settings/google_api_key',
	function ( $value ) {
		return 'AIzaSyBBQRMuAFKzduZVhwWublJFd0VLtJy-uUQ';
	}
);


/* === ACF - register Gutenberg blocks === */

add_action( 'acf/init', 'scoutingnl_acf_init' );

function scoutingnl_acf_init() {

	if ( ! function_exists( 'acf_register_block' ) ) {
		return;
	}

	acf_register_block(
		array(
			'name'            => 'featured_block',
			'title'           => __( 'Featured items', 'scoutingnl' ),
			'description'     => __( 'Gutenberg blok om featured items in te voegen', 'scoutingnl' ),
			'render_callback' => 'scoutingnl_acf_featured_block_render_callback',
			'category'        => 'scouting-blocks',
			'icon'            => 'screenoptions',
			'keywords'        => array( 'featured', 'blok', 'ankeiler', 'nieuws' ),
		)
	);

	acf_register_block(
		array(
			'name'            => 'news_block',
			'title'           => __( 'Nieuws items', 'scoutingnl' ),
			'description'     => __( 'Gutenberg blok om nieuwsitems in te voegen', 'scoutingnl' ),
			'render_callback' => 'scoutingnl_acf_news_block_render_callback',
			'category'        => 'scouting-blocks',
			'icon'            => 'screenoptions',
			'keywords'        => array( 'featured', 'blok', 'ankeiler', 'nieuws' ),
		)
	);

	acf_register_block(
		array(
			'name'            => 'callout_block',
			'title'           => __( 'Callout', 'scoutingnl' ),
			'description'     => __( 'Gutenberg blok om een callout (groen blok met links een afbeelding en rechts een titel, tekst en een knop) in te voegen', 'scoutingnl' ),
			'render_callback' => 'scoutingnl_acf_callout_block_render_callback',
			'category'        => 'scouting-blocks',
			'icon'            => 'screenoptions',
			'keywords'        => array( 'tekst', 'blok', 'ankeiler', 'callout', 'cta' ),
		)
	);

	acf_register_block(
		array(
			'name'            => 'two_columns_block',
			'title'           => __( '2 kolommen', 'scoutingnl' ),
			'description'     => __( 'Gutenberg blok met twee kolommen. Links met een kop + beeld, tekst en een knop. Rechts met een kop, WYSIWYG tekst en een knop', 'scoutingnl' ),
			'render_callback' => 'scoutingnl_acf_two_columns_block_render_callback',
			'category'        => 'scouting-blocks',
			'icon'            => 'screenoptions',
			'keywords'        => array( 'tekst', 'blok', 'WYSIWYG' ),
		)
	);

	acf_register_block(
		array(
			'name'            => 'calendar_block',
			'title'           => __( 'Activiteitenkalender', 'scoutingnl' ),
			'description'     => __( 'Gutenberg blok om de aankomende activiteiten weer te geven', 'scoutingnl' ),
			'render_callback' => 'scoutingnl_acf_calendar_block_render_callback',
			'category'        => 'scouting-blocks',
			'icon'            => 'screenoptions',
			'keywords'        => array( 'kalender', 'blok', 'agenda' ),
		)
	);

	acf_register_block(
		array(
			'name'            => 'gmap_block',
			'title'           => __( 'Google Map', 'scoutingnl' ),
			'description'     => __( 'Gutenberg blok om een Google Map in te voegen', 'scoutingnl' ),
			'render_callback' => 'scoutingnl_acf_gmap_block_render_callback',
			'category'        => 'scoutingnl-blocks',
			'icon'            => 'location',
			'keywords'        => array( 'kaart', 'google maps' ),
		)
	);

}

function scoutingnl_acf_featured_block_render_callback( $block, $content = '', $is_preview = false ) {

	$context               = Timber::get_context();
	$context['block']      = $block;
	$context['fields']     = get_fields();
	$context['is_preview'] = $is_preview;
	Timber::render( 'gutenberg-blocks/gb-featured-items.twig', $context );

}

function scoutingnl_acf_news_block_render_callback( $block, $content = '', $is_preview = false ) {

	$context               = Timber::get_context();
	$context['block']      = $block;
	$context['fields']     = get_fields();
	$context['is_preview'] = $is_preview;
	Timber::render( 'gutenberg-blocks/gb-news-items.twig', $context );

}

function scoutingnl_acf_callout_block_render_callback( $block, $content = '', $is_preview = false ) {

	$context               = Timber::get_context();
	$context['block']      = $block;
	$context['fields']     = get_fields();
	$context['is_preview'] = $is_preview;
	Timber::render( 'gutenberg-blocks/gb-callout.twig', $context );

}

function scoutingnl_acf_two_columns_block_render_callback( $block, $content = '', $is_preview = false ) {

	$context               = Timber::get_context();
	$context['block']      = $block;
	$context['fields']     = get_fields();
	$context['is_preview'] = $is_preview;
	Timber::render( 'gutenberg-blocks/gb-two-columns.twig', $context );

}

function scoutingnl_acf_calendar_block_render_callback( $block, $content = '', $is_preview = false ) {

	$context               = Timber::get_context();
	$context['block']      = $block;
	$context['fields']     = get_fields();
	$context['is_preview'] = $is_preview;
	Timber::render( 'gutenberg-blocks/gb-calendar.twig', $context );

}

function scoutingnl_acf_gmap_block_render_callback( $block, $content = '', $is_preview = false ) {

	$context               = Timber::get_context();
	$context['block']      = $block;
	$context['fields']     = get_fields();
	$context['is_preview'] = $is_preview;
	Timber::render( 'gutenberg-blocks/gb-google-map.twig', $context );

}

add_filter( 'block_categories', 'scoutingnl_gutenberg_plugin_block_categories', 10, 2 );
function scoutingnl_gutenberg_plugin_block_categories( $categories, $post ) {

	return array_merge(
		$categories,
		array(
			array(
				'slug'  => 'scoutingnl-blocks',
				'title' => __( 'scoutingnl custom blokken', '' ),
			),
		)
	);
}

add_filter( 'render_block', 'scoutingnl_wrap_block', 10, 2 );
function scoutingnl_wrap_block( $block_content, $block ) {

	$block_class = '';
	$extra_class = '';
	if ( isset( $block['attrs']['className'] ) ) {
		$block_class = $block['attrs']['className'];
	}

	if ( false === strpos( $block['blockName'], 'acf/' ) ) {
		if ( 2 < strlen( $block_content ) ) {
			$block_content = '<div class="gb-standard container no-padding">' . $block_content . '</div>';
		}
	}

	return $block_content;

}

/* === Nonce lifetime === */

add_filter( 'ppp_nonce_life', 'scoutingnl_ppp_nonce_life' );
function scoutingnl_ppp_nonce_life() {

	return 60 * 60 * 24 * 7;

}


/* === Gravity Forms - Do not store IP address === */

add_filter( 'gform_ip_address', '__return_empty_string' );
