<?php

function scoutingnl_parameter_query_var( $link ) {

	$link = add_query_arg( 'theme', 'scoutingnl', $link );
	return $link;

}


function scoutingnl_bekijk_beta( $thema ) {

	add_filter( 'page_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'post_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'term_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'tag_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'category_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'post_type_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'attachment_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'year_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'month_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'day_link', 'scoutingnl_parameter_query_var' );
	add_filter( 'search_link', 'scoutingnl_parameter_query_var' );

}


add_action( 'pre_get_posts', 'scoutingnl_zoek_queries' );
function scoutingnl_zoek_queries( $query ) {

	if ( ! is_admin() && $query->is_main_query() ) {

		if ( is_search() ) {
			$query->set( 'posts_per_page', AANTAL_ZOEKRESULTATEN_PER_PAGINA );
			$query->set( 'post_type', array( 'post', 'page', 'attachment' ) );
			$query->set( 'post_status', array( 'publish', 'inherit' ) );
		} elseif ( is_archive() && $query->is_main_query() ) {
			// $query->set( 'post_type', array( 'post', 'kalenderitems' ) );
		} else {
			$query->set( 'posts_per_page', AANTAL_RESULTATEN_PER_PAGINA_ARCHIEF );
		}
	}

	return $query;

}


add_filter( 'the_content', 'scoutingnl_verwijder_gallery_shortcode', 0 );
function scoutingnl_verwijder_gallery_shortcode( $content ) {

	add_shortcode( 'gallery', '__return_false' );

	return $content;

}

function scoutingnl_pagina_intro( $pagina ) {

	$intro      = array();
	$args_intro = array(
		'pagename' => $pagina,
	);

	$query_intro = new WP_Query( $args_intro );

	if ( $query_intro->have_posts() ) {

		while ( $query_intro->have_posts() ) {
			$query_intro->the_post();
			$intro['titel']   = get_the_title( $query_intro->ID );
			$intro['content'] = get_the_content( $query_intro->ID );
		}
	}

	return $intro;

}

function scoutingnl_seed( $orderby ) {

	$seed    = floor( time() / ( DAY_IN_SECONDS ) );
	$orderby = str_replace( 'RAND()', "RAND({$seed})", $orderby );
	return $orderby;

}

/* === allow for additional mime types to be uploaded to the media library === */

add_filter( 'upload_mimes', 'scoutingnl_mime_types' );
function scoutingnl_mime_types( $mimes ) {

	$mimes['svg'] = 'image/svg+xml';
	$mimes['swf'] = 'application/x-shockwave-flash';
	return $mimes;

}


add_filter( 'embed_oembed_html', 'scoutingnl_embed_oembed_html', 99, 4 );
function scoutingnl_embed_oembed_html( $cache, $url, $attr, $post_ID ) {

	$classes = array();

	if ( false !== strpos( $url, 'vimeo.com' ) ) {
		$classes[] = 'vimeo';
	}

	if ( false !== strpos( $url, 'youtube.com' ) || false !== strpos( $url, 'youtu.be' ) ) {
		$classes[] = 'youtube';
	}

	return '<span class="' . esc_attr( implode( ' ', $classes ) ) . '">' . $cache . '</span>';

}

/* === Rewrite rules to enable date archives === */

add_action( 'generate_rewrite_rules', 'scoutingnl_rewrite_rules' );
function scoutingnl_rewrite_rules( $wp_rewrite ) {

	$rules             = scoutingnl_generate_date_archives( 'kalenderitems', $wp_rewrite );
	$wp_rewrite->rules = $rules + $wp_rewrite->rules;
	return $wp_rewrite;

}


function scoutingnl_news_excerpt( $id ) {

	$post    = get_post( $id );
	$excerpt = wp_trim_words( $post->post_content, 25, ' ...' );
	return $excerpt;

}

function scoutingnl_generate_date_archives( $type, $wp_rewrite ) {
	$rules = array();

	$post_type    = get_post_type_object( $type );
	$slug_archive = $post_type->has_archive;
	if ( $slug_archive === false ) {
		return $rules;
	}
	if ( $slug_archive === true ) {
		$slug_archive = $post_type->rewrite['slug'];
	}

	$dates = array(
		array(
			'rule' => '([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})',
			'vars' => array( 'year', 'monthnum', 'day' ),
		),
		array(
			'rule' => '([0-9]{4})/([0-9]{1,2})',
			'vars' => array( 'year', 'monthnum' ),
		),
		array(
			'rule' => '([0-9]{4})',
			'vars' => array( 'year' ),
		),
	);

	foreach ( $dates as $data ) {
		$query = 'index.php?post_type=' . $type;
		$rule  = $slug_archive . '/' . $data['rule'];

		$i = 1;
		foreach ( $data['vars'] as $var ) {
			$query .= '&' . $var . '=' . $wp_rewrite->preg_index( $i );
			$i++;
		}

		$rules[ $rule . '/?$' ]                               = $query;
		$rules[ $rule . '/feed/(feed|rdf|rss|rss2|atom)/?$' ] = $query . '&feed=' . $wp_rewrite->preg_index( $i );
		$rules[ $rule . '/(feed|rdf|rss|rss2|atom)/?$' ]      = $query . '&feed=' . $wp_rewrite->preg_index( $i );
		$rules[ $rule . '/page/([0-9]{1,})/?$' ]              = $query . '&paged=' . $wp_rewrite->preg_index( $i );
	}

	return $rules;

}
