<?php
/*
Plugin Name: Scouting groepen Events calendar Widget
Plugin URI:
Description: Provides a calendar widget that displays the upcoming scouting events.
Version: 1.3.2
Author: Hans Rochat
Author URI: 
*/


/**
 * Scouting Event Calendar Widget Class
 */

class Scouting_Calendar_Widget extends WP_Widget {

	public function __construct() {

		parent::__construct( 
			'scoutingnl_calendar_widget', 
			'scoutingnl Events calendar', 
			array( 
				'description' => 'Deze widget genereert een kalender met scouting events in de sidebar.', 
			) 
		);

	}

    public function form( $instance ) {	

		if ( !empty( $instance['title'] ) ) {
			$titel = $instance['title'];
		} else {
			$titel = '...';
		}

        print '<p>';
            print '<label for="' . $this->get_field_id( 'title' ) . '">Titel</label>';
            print '<input class="widefat" id="' . $this->get_field_id( 'title' ) .'" name="' . $this->get_field_name( 'title' ) .'" type="text" value="' . $titel . '" />';
        print '</p>';
     	
    }

    public function update( $new_instance, $old_instance ) {		
		$instance = array();
		$instance['title'] = ( !empty( $new_instance['title'] ) ) ? $new_instance['title'] : 'Belangrijke deadlines';
        return $instance;

    }
    
    public function widget( $args, $instance ) {
	    	
        extract( $args );

		if ( !empty( $instance['title'] ) ) {
			apply_filters( 'widget_title', $instance['title'] );
		}

		print $args['before_widget'];
		
		?>
		<div class="widget_calendar">
			<div id="calendar_wrap">
		    	<?php 
				$scoutingnl_calendar = New Scouting_Calendar;
				print $scoutingnl_calendar->scoutingnl_calendar_toon_calendar();
			    ?>
			</div>
		</div>
	    
	    <?php  
		      
		print $args['after_widget'];
	        
    }
 
	public function scoutingnl_get_events( $jaar, $maand, $dag ) {
		
		global $wpdb;
		$post_types = array( 'kalenderitems' );
		$jaar = filter_var( $jaar, FILTER_VALIDATE_INT );
		$maand = filter_var( $maand, FILTER_SANITIZE_NUMBER_INT );
        $maand = ( 1 === strlen( $maand ) ? '0' . $maand : $maand );		
		$dag = filter_var( $dag, FILTER_VALIDATE_INT ) < 32 ? $dag : 31;
		$dag = ( 1 === strlen( $dag ) ? '0' . $dag : $dag );
		
		$args = array(
			'post_type'      => 'kalenderitems',
			'post_status'    => 'publish',
			'posts_per_page' => -1,
			'meta_query'     => array(
				array(
					'key'     => 'datum',
					'value'   => date( $jaar . $maand . $dag ),
					'type'    => 'DATE',
					'compare' => '=',
				),
			),
		);

		$query = new WP_Query( $args );
		if ( $query->have_posts() ) {
			while( $query->have_posts() ) {
				$query->the_post();
				get_the_title( $query->ID );
			}
			$heeft_events = 1;
		} else {
			$heeft_events = 0;
		}
		wp_reset_postdata( $query );
		return $heeft_events;

	}

}


/**
 * scoutingnl Event calendar Class
 */

class Scouting_Calendar {  
     
    public function __construct() { 
	    
		global $wp;
		$current_url = home_url( add_query_arg( array(), $wp->request ) );
        $this->nav_link = trailingslashit( $current_url );

    }
     
    private $dag_labels = array( 'Ma', 'Di', 'Wo', 'Do', 'Vr', 'Za', 'Zo' );
    private $huidig_jaar = 0;
    private $volgend_jaar = 0;
    private $dit_jaar = 0;
    private $huidige_maand = 0;
    private $huidige_dag = 0;
    private $huidige_datum = null;
    private $aantal_dagen_in_maand = 0;
    private $nav_link = null;
    private $eerstvolgende_event = null;
     
    public function scoutingnl_calendar_toon_calendar() {
	    
        $jaar = null;
        $maand = null;
         
        if ( null == $jaar && isset( $_GET['vj'] ) ) {
            $jaar = filter_var( 
            	$_GET['vj'], 
            	FILTER_VALIDATE_INT, 
            	array( 
            		'options' => array( 
            			'min_range' => date( 'Y', strtotime( '-2 year' ) ), 
            			'max_range' => date( 'Y', strtotime( '+2 year' ) ), 
            		) 
            	) 
            );
            $jaar = ( false === $jaar ) ? date( 'Y' ) : $jaar;
        } elseif ( null == $jaar ) {
            $jaar = date( 'Y', time() );  
        }          
         
        if ( null == $maand && isset( $_GET['vm'] ) ){
            $maand = filter_var( 
            	$_GET['vm'], 
            	FILTER_VALIDATE_INT, 
            	array( 
            		'options' => array( 
            			'min_range' => 1, 
            			'max_range' => 12,
            		) 
            	) 
            );
            $maand = ( false === $maand ) ? date( 'm' ) : $maand;
            $maand = ( 1 === strlen( $maand ) ) ? '0' . $maand : $maand;
        } elseif ( null == $maand ) {
            $maand = date( "m", time() );
        }                  
        
        $this->huidig_jaar = $jaar;
        $this->huidige_maand = $maand;
        $this->aantal_dagen_in_maand = $this->scoutingnl_aantal_dagen_in_maand( $maand, $jaar );  

        $output_calendar = '<div id="container-calendar">';
	    	$output_calendar .= '<div class="calendar-nav">' . $this->scoutingnl_calendar_maak_nav() . '</div>';
	        $output_calendar .= '<div class="calendar">';
		        $output_calendar .= '<ul class="dag-labels">' . $this->scoutingnl_calendar_maak_labels() . '</ul>';   
		        $output_calendar .= '<ul class="datums">';    
		        	$weken_in_maand = $this->scoutingnl_calendar_aantal_weken_in_maand( $maand, $jaar );
		            for ( $i = 0; $i < $weken_in_maand; $i++ ) {
		                for ( $j = 1; $j <= 7; $j++ ) {
		                    $output_calendar .= $this->scoutingnl_calendar_toon_dag( $i * 7 + $j );
		                }
		            }
		        $output_calendar.= '</ul>';
	        $output_calendar.= '</div>';
        $output_calendar.= '</div>';

        return $output_calendar;
         
    }
     
    private function scoutingnl_calendar_toon_dag( $cel ) {
         
        if ( $this->huidige_dag == 0 ) {
	        $eerste_weekdag = date( 'N', strtotime( $this->huidig_jaar . '-' . $this->huidige_maand . '-01' ) );
            if ( intval( $cel ) == intval( $eerste_weekdag ) ) {
                $this->huidige_dag = 1;
            }
        }
                 
        if ( ( $this->huidige_dag != 0 ) && ( $this->huidige_dag <= $this->aantal_dagen_in_maand ) ) {
            $this->huidige_datum = date( 'Y-m-d', strtotime( $this->huidig_jaar . '-' . $this->huidige_maand . '-' . ( $this->huidige_dag ) ) );
	        $calendar = New Scouting_Calendar_Widget();
	        $heeft_events = $calendar->scoutingnl_get_events( $this->huidig_jaar, $this->huidige_maand, $this->huidige_dag );
	        if ( '1' == $heeft_events ) {
		        $cel_inhoud = '<a class="event" title="" href="' . trailingslashit( get_bloginfo( 'url' ) )  . 'kalenderitems/' . $this->huidig_jaar . '/' . $this->huidige_maand . '/' . $this->huidige_dag . '">' . $this->huidige_dag . '</a>';
	        } else {
		        $cel_inhoud = '<span>' . $this->huidige_dag . '</span>';
	        }
			$this->huidige_dag++;   
        } else {
            $this->huidige_datum = null;
           $cel_inhoud = null;
        }

		if ( $this->huidige_datum > date( 'Y-m-d', time() ) && null == $this->eerstvolgende_event && 1 == $heeft_events ) {
			$this->eerstvolgende_event = 1;
			$class_eerstvolgende_event = ' eerstvolgend';
		} else {
			$class_eerstvolgende_event = '';
		}

        return '<li id="li-' . $this->huidige_datum . '" class="datum' . $class_eerstvolgende_event . ( $cel %7 == 1 ? ' start-week' : ( $cel % 7 == 0 ? ' einde-week' : '' ) ) .  ( $this->huidige_datum == null ? ' leeg' : '' ) . ( $this->huidige_datum == date( 'Y-m-d', time() ) ? ' vandaag' : '') . ( $this->huidige_datum < date( 'Y-m-d', time() ) ? ' past' : '') . ( $this->huidige_datum > date( 'Y-m-d', time() ) ? ' future' : '') . '">' . $cel_inhoud . '</li>';
        
    }
     
    private function scoutingnl_calendar_maak_nav(){
         
        $volgende_maand = intval( $this->huidige_maand ) == 12 ? 1 : intval( $this->huidige_maand ) + 1;
        $volgend_jaar = intval( $this->huidige_maand ) == 12 ? intval( $this->huidig_jaar ) + 1 : $this->huidig_jaar;
        $vorige_maand = intval( $this->huidige_maand ) == 1 ? 12 : intval( $this->huidige_maand ) - 1 ;
        $vorig_jaar = intval( $this->huidige_maand ) == 1 ? intval( $this->huidig_jaar ) - 1 : $this->huidig_jaar;
                 
		$nav = '<a class="vorige" href="' . $this->nav_link . '?vm=' . $vorige_maand . '&vj=' . $vorig_jaar . '"><i class="fas fa-angle-left"></i></a>';
		$nav .= '<div class="periode">' . date( 'F Y', strtotime( $this->huidig_jaar . '-' . $this->huidige_maand . '-1' ) ) . '</div>';
		$nav .= '<a class="volgende" href="' . $this->nav_link . '?vm=' . $volgende_maand . '&vj=' . $volgend_jaar . '"><i class="fas fa-angle-right"></i></a>';
		
		return $nav;
            
    }
         
    private function scoutingnl_calendar_maak_labels(){  
           
        $labels = '';
         foreach ( $this->dag_labels as $index => $label ) {
            $labels .= '<li class="' . ( $label == 6 ? 'end-week' : 'start-week' ) . ' title">' . $label . '</li>';
        }
        return $labels;

    }     
     
    private function scoutingnl_calendar_aantal_weken_in_maand( $maand = null, $jaar = null ) {
         
        if ( null == ( $jaar ) ) {
            $jaar = date( 'Y', time() ); 
        }
         
        if ( null == ( $maand ) ) {
            $maand = date( 'm', time() );
        }
         
        $aantal_dagen_in_maand = $this->scoutingnl_aantal_dagen_in_maand( $maand, $jaar );
        $aantal_weken_in_maand = ( $aantal_dagen_in_maand % 7 == 0 ? 0 : 1 ) + intval( $aantal_dagen_in_maand / 7 );
        $laatste_dag_van_maand = date( 'N', strtotime( $jaar . '-' . $maand . '-' . $aantal_dagen_in_maand ) );
        $eerste_dag_van_maand = date( 'N', strtotime( $jaar . '-' . $maand . '-01' ) );
         
        if ( $laatste_dag_van_maand < $eerste_dag_van_maand ) {
            $aantal_weken_in_maand++;
        }
         
        return $aantal_weken_in_maand;
    }
 
    private function scoutingnl_aantal_dagen_in_maand( $maand = null, $jaar = null ) {
         
        if ( null == ( $jaar ) ) {
            $jaar = date( 'Y', time() ); 
		}
        if ( null == ( $maand ) ) {
            $maand = date( 'm', time() );
        }     
        return date( 't', strtotime( $jaar . '-' . $maand . '-01' ) );
    }
     
}

add_action( 'widgets_init', 'scoutingnl_calendar_widget' );
function scoutingnl_calendar_widget() {

	register_widget( 'Scouting_Calendar_Widget' );
	wp_register_style( 'calendar-style', plugins_url( 'style.css', __FILE__ ) );
	wp_enqueue_style( 'calendar-style' );

}